/*
 *  /MathJax/localization/ca/MathML.js
 *
 *  Copyright (c) 2009-2015 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("ca","MathML",{version:"2.6.0",isLoaded:true,strings:{BadMglyph:"Mglyph incorrecte: %1",BadMglyphFont:"Font incorrecta: %1",MathPlayer:"MathJax no ha pogut configurar MathPlayer.\n\nSi MathPlayer no est\u00E0 instal\u00B7lat, necessiteu instal\u00B7lar-lo pr\u00E8viament. Altrament, pot ser que la vostra configuraci\u00F3 de seguretat estigui bloquejant l'execuci\u00F3 de controls ActiveX. Useu el men\u00FA Opcions d'Internet dins el men\u00FA Eines i seleccioneu la pestanya Seguretat, i llavors premeu el bot\u00F3 Nivell Personalitzat. Assegureu-vos que les configuracions per 'Executar Controls ActiveX' i 'Comportaments binari i script' estan activades.\n\nDe moment veureu missatges d'error en comptes de f\u00F3rmules matem\u00E0tiques.",CantCreateXMLParser:"MathJax no pot crear un analitzador XML per MathML. Comproveu que la configuraci\u00F3 de seguretat 'Controls de script ActiveX marcats segurs per scripting' est\u00E0 marcada (aneu a l'opci\u00F3 Opcions d'Internet dins el men\u00FA Eines, i seleccioneu el panell de Seguretat; despr\u00E9s, cliqueu el bot\u00F3 Nivell Personalitzat per activar aquesta configuraci\u00F3).\n\nLes equacions MathML no podran ser processades per MathJax",UnknownNodeType:"Tipus de node desconegut: %1",UnexpectedTextNode:"Node de text inesperat: %1",ErrorParsingMathML:"Error d'an\u00E0lisi MathML",ParsingError:"Error d'an\u00E0lisi MathML: %1",MathMLSingleElement:"MathML ha d'estar format per un sol element",MathMLRootElement:"MathML ha d'estar format per un element \u003Cmath\u003E, no per %1"}});MathJax.Ajax.loadComplete("[MathJax]/localization/ca/MathML.js");
