/*
 *  /MathJax/localization/pt-br/HelpDialog.js
 *
 *  Copyright (c) 2009-2015 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("pt-br","HelpDialog",{version:"2.6.0",isLoaded:true,strings:{Help:"Ajuda do MathJax",MathJax:"*MathJax* \u00E9 uma biblioteca em JavaScript que permite aos autores a inclus\u00E3o de conte\u00FAdo matem\u00E1tico em suas p\u00E1ginas web. Como um renderizador, voc\u00EA n\u00E3o precisa fazer qualquer coisa para que isso ocorra.",Browsers:"*Navegadores*: O MathJax funciona em todos os navegadores modernos incluindo IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+ e a maioria dos navegadores para dispositivos m\u00F3veis.",Menu:"*Menu de F\u00F3rmulas*: O MathJax acrescenta um menu de contexto \u00E0s equa\u00E7\u00F5es. Clique com o bot\u00E3o direito ou pressione CTRL ao clicar em qualquer f\u00F3rmula matem\u00E1tica para acessar o menu.",ShowMath:"*Mostrar F\u00F3rmulas Como* permite que visualize o c\u00F3digo da f\u00F3rmula para copiar e colar (como MathML ou em seu formato original).",Settings:"*Configura\u00E7\u00F5es* oferecem a voc\u00EA o controle sobre os recursos do MathJax, tais como o tamanho das f\u00F3rmulas, e o mecanismo utilizado para exibir equa\u00E7\u00F5es.",Language:"*Idioma* permite que escolha o idioma que o MathJax utiliza em seus menus e mensagens de aviso.",Zoom:"*Zoom nas F\u00F3rmulas*: Se voc\u00EA tem dificuldade para ler uma equa\u00E7\u00E3o, o MathJax pode ampli\u00E1-la para ajud\u00E1-lo a visualiz\u00E1-la melhor.",Accessibilty:"*Acessibilidade*: O MathJax funcionar\u00E1 automaticamente em leitores de tela para tornar as f\u00F3rmulas matem\u00E1ticas acess\u00EDveis aos que possuem problemas de vis\u00E3o.",Fonts:"*Fontes*: O MathJax utilizar\u00E1 certas fontes para f\u00F3rmulas matem\u00E1ticas se elas estiverem instaladas no seu computador; caso contr\u00E1rio, ele utilizar\u00E1 fontes baseadas em web. Embora n\u00E3o seja obrigat\u00F3rio, o uso de fontes instaladas localmente acelerar\u00E1 a diagrama\u00E7\u00E3o. Sugerimos que instale [fontes STIX](%1)."}});MathJax.Ajax.loadComplete("[MathJax]/localization/pt-br/HelpDialog.js");
